<?php
/*
Plugin Name: BuddyPress Links
Plugin URI: http://wordpress.org/extend/plugins/buddypress-links/
Description: BuddyPress Links is a link sharing component for BuddyPress.
Author: Marshall Sorenson (MrMaz)
Author URI: http://marshallsorenson.com
License: GNU GENERAL PUBLIC LICENSE 3.0 http://www.gnu.org/licenses/gpl.txt
Version: 0.9.4.2
Text Domain: buddypress-links
*/

//
// You can override the following constants in
// wp-config.php if you feel the need to.
//
// ***** DO NOT EDIT THIS FILE *****
//

// Define the slug for the component
if ( !defined( 'BP_LINKS_SLUG' ) )
	define( 'BP_LINKS_SLUG', 'links' );

// Define the capability required to manage links
if ( !defined( 'BP_LINKS_CAPABILITY' ) )
	define( 'BP_LINKS_CAPABILITY', 'manage_options' );

// Define a custom theme name to completely bypass any core links themes
// For example, if your active WordPress theme is 'bluesky', and you wanted
// to define your links theme as 'links-custom', you would put your files in:
// /../../wp-content/themes/bluesky/links-custom
if ( !defined( 'BP_LINKS_CUSTOM_THEME' ) )
	define( 'BP_LINKS_CUSTOM_THEME', false );

////////////////////////////////
// Important Internal Constants
// *** DO NOT MODIFY THESE ***

// Configuration
define( 'BP_LINKS_VERSION', '0.9.4.2' );
define( 'BP_LINKS_DB_VERSION', '9' );
define( 'BP_LINKS_PLUGIN_NAME', 'buddypress-links' );
define( 'BP_LINKS_PLUGIN_TEXTDOMAIN', 'buddypress-links' );
define( 'BP_LINKS_THEMES_PATH', 'themes' );
define( 'BP_LINKS_DEFAULT_THEME', 'bp-links-default' );
define( 'BP_LINKS_ADMIN_THEME', 'bp-links-admin' );
define( 'BP_LINKS_ACTIVITY_ACTION_CREATE', 'bp_link_create' );
define( 'BP_LINKS_ACTIVITY_ACTION_VOTE', 'bp_link_vote' );
define( 'BP_LINKS_ACTIVITY_ACTION_COMMENT', 'bp_link_comment' );

// Core Paths
define( 'BP_LINKS_PLUGIN_DIR', dirname( __FILE__ ) );
define( 'BP_LINKS_PLUGIN_URL', WP_PLUGIN_URL . '/' . BP_LINKS_PLUGIN_NAME );
define( 'BP_LINKS_LIB_DIR', BP_LINKS_PLUGIN_DIR . '/lib' );

// Sub Paths
define( 'BP_LINKS_THEMES_DIR', BP_LINKS_PLUGIN_DIR . '/' . BP_LINKS_THEMES_PATH );
define( 'BP_LINKS_THEMES_URL', BP_LINKS_PLUGIN_URL . '/' . BP_LINKS_THEMES_PATH );
define( 'BP_LINKS_ADMIN_THEME_DIR', BP_LINKS_THEMES_DIR . '/' . BP_LINKS_ADMIN_THEME );
define( 'BP_LINKS_ADMIN_THEME_URL', BP_LINKS_THEMES_URL . '/' . BP_LINKS_ADMIN_THEME );
define( 'BP_LINKS_ADMIN_THEME_URL_INC', BP_LINKS_ADMIN_THEME_URL . '/_inc' );

// ***************************
///////////////////////////////

//
// Plugin Compatibility Functions
//

/**
 * Check if activity component is enabled
 *
 * @return boolean
 */
function bp_links_is_activity_enabled() {
	return ( class_exists( 'BP_Activity_Component', false ) );
}

/**
 * Check if friends component is enabled
 *
 * @return boolean
 */
function bp_links_is_friends_enabled() {
	return ( class_exists( 'BP_Friends_Component', false ) );
}

//
// Plugin Bootstrap Functions
//

/**
 * Set up root component
 */
function bp_links_setup_root_component() {
	// Register 'links' as a root component
	bp_core_add_root_component( 'links' );
}

/**
 * Set up globals.
 *
 * @global Buddypress $bp
 * @global wpdb $wp
 */
function bp_links_setup_globals() {
	global $bp, $wpdb;

	$bp->links = new stdClass();

	/* For internal identification NEVER, EVER, CHANGE THIS */
	$bp->links->id = 'links';
	$bp->links->slug = BP_LINKS_SLUG;
	$bp->links->root_slug = isset( $bp->pages->links->slug ) ? $bp->pages->links->slug : BP_LINKS_SLUG;
	$bp->links->name = __( 'Links', 'buddypress-links' );

	$bp->links->table_name = $wpdb->prefix . 'bp_links';
	$bp->links->table_name_categories = $wpdb->prefix . 'bp_links_categories';
	$bp->links->table_name_votes = $wpdb->prefix . 'bp_links_votes';
	$bp->links->table_name_linkmeta = $wpdb->prefix . 'bp_links_linkmeta';
	$bp->links->format_notification_function = 'bp_links_format_notifications';

	/* Register this in the active components array */
	$bp->active_components[$bp->links->slug] = $bp->links->id;

	$bp->links->forbidden_names =
		apply_filters( 'bp_links_forbidden_names',
			array(
				// internal
				'add',
				'admin',
				'all',
				'create',
				'delete',
				'feed',
				'links',
				'my-links',
				'submit',
				// order by filter
				'active',
				'high-votes',
				'most-votes',
				'newest',
				'popular',
				// category url slug
				BP_LINKS_CAT_URL_SLUG
			)
		);
}

/**
 * Handle special BP initialization
 */
function bp_links_init()
{
	// load links component
	require_once BP_LINKS_PLUGIN_DIR . '/bp-links-component.php';

	// post init hook
	do_action( 'bp_links_init' );
}
add_action( 'bp_include', 'bp_links_init' );

/**
 * Handle activation
 */
function bp_links_activate()
{
	// load upgrade tools
	require_once( 'bp-links-upgrade.php' );
	// make sure its initialized
	bp_links_init();
	// make sure component is set up
	bp_links_setup_component();
	// run upgrader
	bp_links_upgrade();
}
register_activation_hook( __FILE__, 'bp_links_activate' );
